aboutsummaryrefslogtreecommitdiffstats
path: root/lib/rfsv.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/rfsv.h')
-rw-r--r--lib/rfsv.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/lib/rfsv.h b/lib/rfsv.h
index dbed2c9..c497f67 100644
--- a/lib/rfsv.h
+++ b/lib/rfsv.h
@@ -363,14 +363,15 @@ public:
/**
* Retrieves details about a drive.
*
- * @param dev An integer, representing the drive to get details from.
+ * @param drive The drive character of the drive to get details from
+ * (e.g: 'C', 'D' etc.).
* (0 represents A:, 1 is B: and so on ...)
* @param drive A @ref PlpDrive object which is filled with the drive's
* information upon return.
*
* @returns A Psion error code (One of enum @ref #errs ).
*/
- virtual Enum<errs> devinfo(const u_int32_t dev, PlpDrive &drive) = 0;
+ virtual Enum<errs> devinfo(const char drive, PlpDrive &dinfo) = 0;
/**
* Reads from a file on the Psion.
@@ -363,14 +363,15 @@ public:
* (0 represents A:, 1 is B: and so on ...)
- * @param drive A @ref PlpDrive object which is filled with the drive's
+ * @param dinfo A @ref PlpDrive object which is filled with the drive's
* information upon return.
*